@@ -13,6 +13,7 @@ var group__spa__keys =
     [ "SPA_KEY_API_ALSA_IGNORE_DB", "group__spa__keys.html#gad13b0f3fd7970f7bb1332782ff8d649e", null ],
     [ "SPA_KEY_API_ALSA_OPEN_UCM", "group__spa__keys.html#ga98db635729354c31033c8fe16fd28f00", null ],
     [ "SPA_KEY_API_ALSA_DISABLE_LONGNAME", "group__spa__keys.html#gab67f1f5fc3425c08a37874cbf7ac1afb", null ],
+    [ "SPA_KEY_API_ALSA_BIND_CTLS", "group__spa__keys.html#gabf1db673167d7f06ee3b9ac380f03218", null ],
     [ "SPA_KEY_API_ALSA_CARD_ID", "group__spa__keys.html#gae257876566997855b6cc94aa12c60d85", null ],
     [ "SPA_KEY_API_ALSA_CARD_COMPONENTS", "group__spa__keys.html#ga397212748e5208c2727994b89ab56b04", null ],
     [ "SPA_KEY_API_ALSA_CARD_DRIVER", "group__spa__keys.html#gaa99aa65c64f6fb207cc7b567a59d759b", null ],
@@ -34,6 +35,7 @@ var group__spa__keys =
     [ "SPA_KEY_API_LIBCAMERA", "group__spa__keys.html#gaba357c4725e9bed3857fbeb058cd4380", null ],
     [ "SPA_KEY_API_LIBCAMERA_PATH", "group__spa__keys.html#ga5a5b6f28a0185f7c9740abfeb86a9f55", null ],
     [ "SPA_KEY_API_LIBCAMERA_LOCATION", "group__spa__keys.html#gaa6165b48b161efa69a759aefa0c591f8", null ],
+    [ "SPA_KEY_API_LIBCAMERA_ROTATION", "group__spa__keys.html#ga272352dcc80a4c712a58026760af405d", null ],
     [ "SPA_KEY_API_LIBCAMERA_CAP_DRIVER", "group__spa__keys.html#ga102acfa48ef947978f6dbd43198b40b8", null ],
     [ "SPA_KEY_API_LIBCAMERA_CAP_CARD", "group__spa__keys.html#gad3ec15b6e5bbdd02f195a2356f2282de", null ],
     [ "SPA_KEY_API_LIBCAMERA_CAP_BUS_INFO", "group__spa__keys.html#ga49c1389221d9ad4088cb33f468ff8399", null ],
@@ -56,7 +58,9 @@ var group__spa__keys =
     [ "SPA_KEY_API_BLUEZ5_CODEC", "group__spa__keys.html#gae40f1dac2ce129ce24536b84f18464a6", null ],
     [ "SPA_KEY_API_BLUEZ5_CLASS", "group__spa__keys.html#ga3922fb11532f928abf055d8b9be5ec03", null ],
     [ "SPA_KEY_API_BLUEZ5_ICON", "group__spa__keys.html#ga715d922eb1e490c97f4d8925ac4b8ebe", null ],
+    [ "SPA_KEY_API_BLUEZ5_ROLE", "group__spa__keys.html#gadf50fc8fd87773ea21c53db357e38ae6", null ],
     [ "SPA_KEY_API_JACK", "group__spa__keys.html#ga7793a8ed3c5fb1376a56750470c24832", null ],
     [ "SPA_KEY_API_JACK_SERVER", "group__spa__keys.html#ga4bf94a46ddb513183c1d2dff8bcbacda", null ],
-    [ "SPA_KEY_API_JACK_CLIENT", "group__spa__keys.html#gab4566b9446b8eb81b67632beb35f4612", null ]
+    [ "SPA_KEY_API_JACK_CLIENT", "group__spa__keys.html#gab4566b9446b8eb81b67632beb35f4612", null ],
+    [ "SPA_KEY_API_GLIB_MAINLOOP", "group__spa__keys.html#gac5fdbd387e707ad221447e71724c86ca", null ]
 ];
\ No newline at end of file
